'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _composeMiddleware = require('compose-middleware');

var _composeMiddleware2 = _interopRequireDefault(_composeMiddleware);

var _httpStatus = require('http-status');

var _httpStatus2 = _interopRequireDefault(_httpStatus);

var _passport = require('passport');

var _passport2 = _interopRequireDefault(_passport);

var _passport3 = require('./local/passport');

var _passport4 = _interopRequireDefault(_passport3);

var _passport5 = require('./facebook/passport');

var _passport6 = _interopRequireDefault(_passport5);

var _user = require('../../shared/user/user.service');

var _user2 = _interopRequireDefault(_user);

var _auth = require('../../shared/auth/auth.service');

var _auth2 = _interopRequireDefault(_auth);

var _env = require('../../config/env');

var _env2 = _interopRequireDefault(_env);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @function initialize
 * @description Register authenticate strategies
 */
function initialize() {
    (0, _passport4.default)(_user2.default);
    (0, _passport6.default)(_user2.default, _env2.default.facebook);
}

function register() {
    return _composeMiddleware2.default.compose(bodyToParamsMiddleware, function (reg, res, next) {
        reg.params = reg.body;

        _user2.default.findOneBy({ email: reg.params.email }).then(function (result) {
            if (result) {
                res.status(_httpStatus2.default.BAD_REQUEST).json({
                    code: 'NOT_UNIQUE_EMAIL',
                    error: 'Email address already exists'
                });
            } else {
                next();
            }
        });
    }, function (reg, res, next) {
        _user2.default.createUser(reg.params).then(function () {
            next();
        }).catch(next);
    }, createPassportAuthenticateMiddleware('local'), generateTokenControllerAction);
}

function login() {
    return _composeMiddleware2.default.compose(bodyToParamsMiddleware, createPassportAuthenticateMiddleware('local'), generateTokenControllerAction);
}

function facebookLoginWithAccessToken() {
    return _composeMiddleware2.default.compose(bodyToParamsMiddleware, createPassportAuthenticateMiddleware('facebook-token'), generateTokenControllerAction);
}

function bodyToParamsMiddleware(req, res, next) {
    req.params = req.body;
    next();
}

function generateTokenControllerAction(req, res) {
    res.json({
        user: req.user,
        token: _auth2.default.generateToken(req.user._id)
    });
}

function createPassportAuthenticateMiddleware(strategyName) {
    return _passport2.default.authenticate(strategyName, {
        session: false
    });
}

exports.default = {
    register: register,
    login: login,
    facebookLoginWithAccessToken: facebookLoginWithAccessToken,
    initialize: initialize
};
module.exports = exports['default'];
//# sourceMappingURL=auth.controller.js.map
