'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.default = setup;

var _passport = require('passport');

var _passport2 = _interopRequireDefault(_passport);

var _passportFacebookToken = require('passport-facebook-token');

var _passportFacebookToken2 = _interopRequireDefault(_passportFacebookToken);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @function setup
 * @description Register facebook authentication strategy
 * @param {Object} UserService
 * @param {Object} facebookConfig
 */
/* istanbul ignore next */
// Should be ignored for now because of third party dependency. So API tests can't help

function setup(UserService, facebookConfig) {
    _passport2.default.use(new _passportFacebookToken2.default({
        clientID: facebookConfig.clientID,
        clientSecret: facebookConfig.clientSecret
    }, function (accessToken, refreshToken, profile, done) {
        var mainPublicEmail = profile.emails[0].value;

        if (!mainPublicEmail) {
            // Some times it happens
            // https://developers.facebook.com/bugs/298946933534016/?comment_id=620710881344692
            // https://developers.facebook.com/docs/graph-api/reference/user
            done(new Error('Facebook Auth: Not found e-mail in profile'));
            return;
        }

        UserService.findOrCreateUser({
            email: mainPublicEmail
        }, {
            email: mainPublicEmail,
            name: profile.displayName,
            facebookId: profile.id
        }).then(function (user) {
            done(null, user);
        }).catch(done);
    }));
}
module.exports = exports['default'];
//# sourceMappingURL=passport.js.map
