'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _mapView = require('./map-view.model');

var _mapView2 = _interopRequireDefault(_mapView);

var _sensor = require('../sensors/sensor.model');

var _sensor2 = _interopRequireDefault(_sensor);

var _files = require('../files/files.service');

var _files2 = _interopRequireDefault(_files);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var mapViewService = {
    getById: getById,
    create: create,
    updatePicture: updatePicture,
    update: update
};

exports.default = mapViewService;


function getById(id) {
    return _mapView2.default.findById(id).populate(getSensorPopulationConfig()).then(function (mapView) {
        return new _mapView2.default(mapView);
    });
}

function getSensorPopulationConfig() {
    return {
        path: 'sensors.sensor',
        model: _sensor2.default
    };
}

function create(createDto) {
    return new _mapView2.default(createDto).save().then(onActionCompleted);
}

function updatePicture(id, newName) {

    return getById(id).then(onReceived).then(onActionCompleted);

    function onReceived(mapViewModel) {
        return _files2.default.tryDeleteFile(mapViewModel.pictureName).then(onOldPictureRemoved);

        function onOldPictureRemoved() {
            return _mapView2.default.findByIdAndUpdate(id, { pictureName: newName });
        }
    }
}

function update(model) {
    var id = model._id;
    delete model._id;

    return _mapView2.default.update({ '_id': id }, { $set: model }).then(function () {
        return getById(id);
    });
}

function onActionCompleted(_ref) {
    var id = _ref.id;

    return getById(id);
}
module.exports = exports['default'];
//# sourceMappingURL=map-view.service.js.map
