'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _mongoose = require('mongoose');

var _mongoose2 = _interopRequireDefault(_mongoose);

var _httpStatus = require('http-status');

var _httpStatus2 = _interopRequireDefault(_httpStatus);

var _APIError = require('../helpers/APIError');

var _APIError2 = _interopRequireDefault(_APIError);

var _sensor = require('./sensor.hooks');

var _sensor2 = _interopRequireDefault(_sensor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var Schema = _mongoose2.default.Schema;
/**
 * Sensor Schema
 */

var SensorSchema = new Schema({
    description: {
        type: String
    },
    type: {
        type: String
    },
    subType: {
        type: String
    },
    executor: {
        type: Boolean,
        default: false
    },
    servo: {
        type: Boolean,
        default: false
    },
    metrics: {
        type: String
    },
    mqttId: {
        type: 'String',
        unique: true,
        required: true
    },
    value: {
        type: Schema.Types.Mixed,
        required: false
    },
    valueUpdated: {
        type: Date,
        required: false
    }
});

/**
 * Methods
 */
SensorSchema.method({});

/**
 * Statics
 */
SensorSchema.statics = {
    /**
     * Get sensor
     * @param {ObjectId} id - The objectId of sensor.
     * @returns {Promise<Sensor, APIError>}
     */
    get: function get(id) {
        return this.findById(id).execAsync().then(function (sensor) {
            if (sensor) {
                return sensor;
            }
            var err = new _APIError2.default('No such sensor exists!', _httpStatus2.default.NOT_FOUND);
            return _bluebird2.default.reject(err);
        });
    }
};

_sensor2.default.createHooks(SensorSchema);

exports.default = _mongoose2.default.model('Sensor', SensorSchema);
module.exports = exports['default'];
//# sourceMappingURL=sensor.model.js.map
