'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

exports.default = function (io) {

    io.on('connection', onConnection);

    function onConnection(socket) {
        var subscribedDevices = new Set();

        socket.on('subscribe', onSubscribe);
        socket.on('unsubscribe', onUnsubscribe);
        socket.on('disconnect', onDisconnect);
        socket.on('pushEvent', onEventRaised);

        var subscriber = _input2.default.stream.filter(function (m) {
            return m.event === 'device-add' || m.event === 'status' && subscribedDevices.has(m.device);
        }).subscribe(onEvent, onError);

        function onSubscribe(config) {
            subscribedDevices.add(config.device);
        }

        function onUnsubscribe(config) {
            subscribedDevices.delete(config.device);
        }

        function onEventRaised(config) {
            _output2.default.write({
                event: 'status',
                device: config.device,
                value: config.value.toString()
            });
        }

        function onEvent(event) {
            socket.emit('event', event);
        }

        function onError(err) {
            debug('Something went wrong: ' + err.message);
        }

        function onDisconnect() {
            subscriber.unsubscribe();
            debug('Socket disconnected');
        }
    }
};

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _input = require('../../data-streams/input');

var _input2 = _interopRequireDefault(_input);

var _output = require('../../data-streams/output');

var _output2 = _interopRequireDefault(_output);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var debug = (0, _debug2.default)('SH_BE:device-events'); /**
                                                          * @file provides an API for WS clients to subscribe to device events
                                                          * 
                                                          * USAGE EXAMPLE
                                                          * ```
                                                          * var socket = io('ws://localhost:3000');
                                                          * 
                                                          * socket.on('connect', ()=>log('connect'));
                                                          * socket.on('event', (event)=>log(event));
                                                          * 
                                                          * // immediately subscribes to an 'iddqd' device
                                                          * subscribe('iddqd');
                                                          * // subscribes to 'primary' in 5 seconds
                                                          * setTimeout(()=>{ subscribe('primary'); }, 5000);
                                                          * 
                                                          * function log(message){
                                                          *    console.log(`t ${ +new Date }`, message);
                                                          *  }
                                                          * 
                                                          * function subscribe(device){
                                                          *   socket.emit('subscribe', { device });
                                                          * }
                                                          * ``` 
                                                          */

module.exports = exports['default'];
//# sourceMappingURL=device-events.js.map
