'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _APIError = require('../helpers/APIError');

var _APIError2 = _interopRequireDefault(_APIError);

var _httpStatus = require('http-status');

var _httpStatus2 = _interopRequireDefault(_httpStatus);

var _timeseries = require('./timeseries.service');

var _timeseries2 = _interopRequireDefault(_timeseries);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

var _sensor = require('../sensors/sensor.model');

var _sensor2 = _interopRequireDefault(_sensor);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var CHILD_PERIODS = {
    'day': 'hour',
    'week': 'day',
    'month': 'day',
    'year': 'month'
};

function query(req, res, next) {

    if (!req.query.period || !CHILD_PERIODS.hasOwnProperty(req.query.period)) {
        var err = new _APIError2.default('Period is not provided to wrong', _httpStatus2.default.BAD_REQUEST);
        return next(err);
    }

    var _req$query = req.query,
        sensor = _req$query.sensor,
        period = _req$query.period;

    var devices = _timeseries2.default.getDevicesStatistic();
    var from = (0, _moment2.default)().subtract(1, period);

    devices[sensor].getCollection(from.toDate(), CHILD_PERIODS[period]).toArray().then(function (data) {
        res.json({
            sensor: sensor,
            measurementUnit: req.metrics,
            data: data.map(function (item) {
                return { date: item.startDate, value: item.data.average };
            })
        });
    }).catch(next);
}

function getSensor(req, res, next) {

    if (!req.query.sensor) {
        var err = new _APIError2.default('Sensor is not provided', _httpStatus2.default.BAD_REQUEST);
        return next(err);
    }

    _sensor2.default.findOne({ mqttId: req.query.sensor }).then(function (sensor) {
        req.metrics = sensor.metrics;
        return next();
    }).error(function (e) {
        return next(e);
    });
}

exports.default = { query: query, getSensor: getSensor };
module.exports = exports['default'];
//# sourceMappingURL=timeseries.controller.js.map
