'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _env = require('../config/env');

var _env2 = _interopRequireDefault(_env);

var _mqtt = require('mqtt');

var _mqtt2 = _interopRequireDefault(_mqtt);

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _input = require('../data-streams/input');

var _input2 = _interopRequireDefault(_input);

var _output = require('../data-streams/output');

var _output2 = _interopRequireDefault(_output);

var _convertMqttMessageToEvent = require('./event/convert-mqtt-message-to-event');

var _convertMqttMessageToEvent2 = _interopRequireDefault(_convertMqttMessageToEvent);

var _eventType = require('./event/event-type');

var _topicPrefix = require('./topic-prefix');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @file Reads config for the mqqt broker address,
 * connects to it and provides event data to the data hub
 */

var debug = (0, _debug2.default)('SH_BE:mqtt-client');

// Create a client connection

var client = _mqtt2.default.connect({
    host: _env2.default.mqtt.hostname,
    port: _env2.default.mqtt.port,
    auth: _env2.default.mqtt.username + ':' + _env2.default.mqtt.password
});

client.on('connect', onMqttConnect).on('message', onMqttMessage);

function onMqttConnect() {
    client.subscribe(_topicPrefix.INPUT + '#');
    _output2.default.stream.subscribe(onInputEvent);
}

function onMqttMessage(topic, rawMessage) {
    debug('MQTT >>. Got message: topic \'' + topic + '\', message: \'' + rawMessage.toString() + '\'');
    var event = (0, _convertMqttMessageToEvent2.default)(topic, rawMessage);

    _input2.default.write(event);
    debug('Added to input stream event: \'' + JSON.stringify(event) + '\'');
}

function onInputEvent(event) {
    if (event.event === _eventType.DEVICE_STATUS) {
        client.publish(_topicPrefix.OUTPUT + event.device, event.value);
    } else {
        debug('Unknown output stream event received: \'' + JSON.stringify(event) + '\'');
    }
}

exports.default = client;
module.exports = exports['default'];
//# sourceMappingURL=client.js.map
