'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var COMPARISON_OPERATORS = {
    'GREATER_THAN': '>',
    'GREATER_THAN_OR_EQUAL_TO': '>=',
    'LESS_THAN': '<',
    'LESS_THAN_OR_EQUAL_TO': '<=',
    'EQUAL_TO': '===',
    'NOT_EQUAL': '!=='
};

var LOGICAL_OPERATORS = {
    'AND': '&&',
    'OR': '||'
};

function convertScenario(scenario) {
    return new Promise(function (resolve, reject) {
        if (!scenario) {
            return reject('No scenario JSON received!');
        }

        if (!scenario.actions || !scenario.actions.length) {
            return reject('Incorrect scenario JSON received!');
        }

        if (scenario.conditions && scenario.conditions.length >= 2 && !scenario.logicalOperator) {
            return reject('Missing logical operator!');
        }

        return resolve('SMART_HOUSE\n                .get_api(\'0.0.1\')\n                .then(function(api){\n                    ' + getScriptBody(scenario) + '\n                });');
    });
}

function getScriptBody(scenario) {
    if (scenario.conditions && scenario.conditions.length) {
        return 'api.on(\'message\', [' + getDeviceList(scenario.conditions) + '], function () {\n                if (' + getConditions(scenario.conditions, scenario.logicalOperator) + ') {\n                    ' + getActions(scenario.actions) + '\n                }\n            });';
    } else {
        return getActions(scenario.actions);
    }
}

function getConditions(conditions, logicalOperator) {
    return conditions.reduce(function (conditionsList, condition) {
        return [].concat(_toConsumableArray(conditionsList), ['api.device.get(\'' + condition.device + '\').value ' + COMPARISON_OPERATORS[condition.condition] + ' ' + condition.value]);
    }, []).join('\n' + LOGICAL_OPERATORS[logicalOperator] + ' ');
}

function getActions(actions) {
    return actions.reduce(function (actionsString, action) {
        return actionsString + ('api.device.get(\'' + action.device + '\').send(\'' + action.value + '\');\n');
    }, '');
}

function getDeviceList(list) {
    return list.map(function (listItem) {
        return '\'' + listItem.device + '\'';
    }).join(', ');
}

exports.default = { convertScenario: convertScenario };
module.exports = exports['default'];
//# sourceMappingURL=scenario.converter.js.map
