'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.start = exports.stop = undefined;

var _child_process = require('child_process');

var _filtered = require('../data-streams/filtered.input');

var _input = require('../data-streams/input');

var _output = require('../data-streams/output');

var runningScenarios = new Map();

_filtered.stream.subscribe(notifyScenarios);

function run(scenario) {
    var scenarioProcess = (0, _child_process.fork)(__dirname + '/scenario-runner/runner', [scenario.body]);
    runningScenarios.set(scenario.id, scenarioProcess);

    scenarioProcess.on('message', function (_ref) {
        var type = _ref.type,
            content = _ref.content;

        if (type === 'message') {
            _output.stream.next(content);
        }
    });

    scenarioProcess.on('exit', function (code) {
        //when we end the process manually, we do not send an error code, but it is present if the process ends itself
        var isKilledManually = code === null;

        runningScenarios.delete(scenario.id);

        if (!isKilledManually) {
            scenario.updateAsync({ active: false }).then(function () {
                _input.stream.next({
                    id: scenario.id,
                    active: false,
                    event: 'scenario-status-change'
                });
            });
        }
    });
}

function isRunning(scenario) {
    return runningScenarios.has(scenario.id);
}

function start(scenario) {
    if (isRunning(scenario)) {
        var scenarioProcess = runningScenarios.get(scenario.id);

        stop(scenario);
        scenarioProcess.on('exit', function () {
            return run(scenario);
        });
    } else {
        run(scenario);
    }
}

function notifyScenarios(message) {
    runningScenarios.forEach(function (scenario) {
        scenario.send({
            type: 'message',
            content: message
        });
    });
}

function stop(scenario) {
    var scenarioProcess = runningScenarios.get(scenario.id);
    if (scenarioProcess) {
        scenarioProcess.kill();
    }
}

exports.stop = stop;
exports.start = start;
//# sourceMappingURL=scenario.manager.js.map
