'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _mongoose = require('mongoose');

var _mongoose2 = _interopRequireDefault(_mongoose);

var _scenario = require('./scenario.manager');

var scenarioManager = _interopRequireWildcard(_scenario);

var _scenario2 = require('./scenario.converter');

var _scenario3 = _interopRequireDefault(_scenario2);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Scenario Schema
 */

var ScenarioSchema = new _mongoose2.default.Schema({
    name: {
        type: String,
        required: true
    },
    description: String,
    active: {
        type: Boolean,
        default: false
    },
    body: String, // holds javascript content
    wizard: Object, // holds wizard content
    isConvertable: {
        type: Boolean,
        default: false
    }
});

/**
 * Methods
 */
ScenarioSchema.method({});

/**
 * Statics
 */
ScenarioSchema.statics = {
    /**
     * Get sensor
     * @param {ObjectId} id - The objectId of scenario.
     * @returns {Promise<Sensor, undefined>}
     */
    get: function get(id) {
        return this.findById(id).execAsync().then(function (scenario) {
            if (scenario) {
                return scenario;
            }

            return _bluebird2.default.reject();
        });
    }
};

ScenarioSchema.options.toJSON = ScenarioSchema.options.toObject = {
    transform: function transform(doc, ret) {
        delete ret.__v;
        delete ret._id;
        ret.id = doc._id.toString();
        return ret;
    }
};

ScenarioSchema.pre('validate', function (next) {
    var _this = this;

    if (!this.isConvertable || !this.wizard) {
        next();
    }

    _scenario3.default.convertScenario(this.wizard).then(function (jsBody) {
        _this.body = jsBody;
        next();
    }).catch(next);
});

ScenarioSchema.post('save', function (scenario) {
    if (scenario.active) {
        scenarioManager.start(scenario);
    } else {
        scenarioManager.stop(scenario);
    }
});

ScenarioSchema.post('remove', function (scenario) {
    scenarioManager.stop(scenario);
});

exports.default = _mongoose2.default.model('Scenario', ScenarioSchema);
module.exports = exports['default'];
//# sourceMappingURL=scenario.model.js.map
