'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _composeMiddleware = require('compose-middleware');

var _composeMiddleware2 = _interopRequireDefault(_composeMiddleware);

var _jsonwebtoken = require('jsonwebtoken');

var _jsonwebtoken2 = _interopRequireDefault(_jsonwebtoken);

var _expressJwt = require('express-jwt');

var _expressJwt2 = _interopRequireDefault(_expressJwt);

var _httpStatus = require('http-status');

var _httpStatus2 = _interopRequireDefault(_httpStatus);

var _env = require('../../config/env');

var _env2 = _interopRequireDefault(_env);

var _user = require('../user/user.service');

var _user2 = _interopRequireDefault(_user);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var validateJwt = (0, _expressJwt2.default)({ secret: _env2.default.token.secret });

/**
 * @function ensureAuthenticated
 * @description Attaches the user object to the request if authenticated
 * Otherwise returns 403
 * @return {Object}
 */
function ensureAuthenticated() {
    return _composeMiddleware2.default.compose(validateJwt, function (req, res, next) {
        var id = req.user && req.user._id;
        _user2.default.getUserById(id).then(function (user) {
            req.user = user;
            next();
        }).catch(function () {
            res.status(_httpStatus2.default.BAD_REQUEST).json({
                code: 'USER_NOT_EXIST',
                error: 'user not exist'
            });
        });
    });
}

/**
 * @function hasRole
 * @description Checks if the user role meets the minimum requirements of the route
 * @param {String} roleRequired
 * @return {Object}
 */
function hasRole(roleRequired) {
    if (!roleRequired) throw new Error('Required role needs to be set');

    return _composeMiddleware2.default.compose(ensureAuthenticated(), function (req, res, next) {
        if (_env2.default.userRoles.indexOf(req.user.role) >= _env2.default.userRoles.indexOf(roleRequired)) {
            next();
        } else {
            res.status(_httpStatus2.default.FORBIDDEN).json({
                code: 'ACCESS_FORBIDDEN',
                error: 'Access forbidden'
            });
        }
    });
}

/**
 * @function generateToken
 * @description Returns a jwt token signed by the app secret
 * @param {Number} id
 */
function generateToken(id) {
    return _jsonwebtoken2.default.sign({ _id: id }, _env2.default.token.secret, { expiresIn: _env2.default.token.expires });
}

exports.default = {
    hasRole: hasRole,
    ensureAuthenticated: ensureAuthenticated,
    generateToken: generateToken
};
module.exports = exports['default'];
//# sourceMappingURL=auth.service.js.map
