'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _mongoose = require('mongoose');

var _mongoose2 = _interopRequireDefault(_mongoose);

var _crypto = require('crypto');

var _crypto2 = _interopRequireDefault(_crypto);

var _mongooseFindorcreate = require('mongoose-findorcreate');

var _mongooseFindorcreate2 = _interopRequireDefault(_mongooseFindorcreate);

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * @file User Schema
 */
var UserSchema = new _mongoose2.default.Schema({
    name: {
        type: String,
        required: true
    },
    email: {
        type: String,
        unique: true,
        required: true
    },
    role: {
        type: String,
        default: 'user'
    },
    facebookId: { type: Number },
    salt: { type: String },
    hashedPassword: { type: String }
}, {
    collection: 'users',
    toObject: {
        transform: function transform(doc, ret) {
            delete ret.salt;
            delete ret.hashedPassword;
            delete ret.__v;
            return ret;
        }
    }
});

UserSchema.virtual('password').set(function (password) {
    this._password = password;
    this.salt = makeSalt();
    this.hashedPassword = encryptPassword(password, this.salt);
}).get(function () {
    return this._password;
});

/**
 * @function
 * @description Make salt for password private method
 * @return {String}
 */
function makeSalt() {
    return _crypto2.default.randomBytes(16).toString('base64');
}

/**
 * @function encryptPassword
 * @description encrypt password private method
 * @param {String} password
 * @param {String} salt
 * @return {String}
 */
function encryptPassword(password, salt) {
    var encryptedPassword = '';

    if (password && salt) {
        var saltBuffer = new Buffer(salt, 'base64');
        encryptedPassword = _crypto2.default.pbkdf2Sync(password, saltBuffer, 10000, 64, 'sha1').toString('base64');
    }

    return encryptedPassword;
}

UserSchema.methods = {
    /**
     * @function authenticate
     * @description Check is password correct
     * @param {String} plainText
     * @return {Boolean}
     */
    authenticate: function authenticate(plainText) {
        return encryptPassword(plainText, this.salt) === this.hashedPassword;
    }
};

UserSchema.plugin(_mongooseFindorcreate2.default);
UserSchema.statics.findOrCreate = _bluebird2.default.promisify(UserSchema.statics.findOrCreate);

exports.default = _mongoose2.default.model('User', UserSchema);
module.exports = exports['default'];
//# sourceMappingURL=user.model.js.map
