'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _user = require('./user.model');

var _user2 = _interopRequireDefault(_user);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var REMOVED_FIELDS = '-salt -hashedPassword -__v';

/**
 * @function isPasswordCorrect
 * @description It will authenticate user password
 * @param {Object} user
 * @param {String} password
 * @return {Boolean}
 */
function isPasswordCorrect(user, password) {
    return user.authenticate(password);
}

/**
 * @function findOneBy
 * @description It will find one user by query
 * @param {Object} query
 * @return {object}
 */
function findOneBy(query) {
    return _user2.default.findOne(query);
}

/**
 * @function getAllUsers
 * @description It will return all users
 * @return {Array}
 */
function getAllUsers() {
    return _user2.default.find({}, REMOVED_FIELDS);
}

/**
 * @function getUserById
 * @description It will return user by id
 * @param {Number} userId
 * @return {object}
 */
function getUserById(userId) {
    return _user2.default.findById(userId, REMOVED_FIELDS);
}

/**
 * @function createUser
 * @description It will create new user in database
 * @param {object} body
 * @return {object}
 */
function createUser(body) {
    return _user2.default.create(body);
}

/* istanbul ignore next */
// Ignored until coverage report will be fixed

/**
 * @function findOrCreateUser
 * @description It will find user by query or create new user in database
 * @param {object} query
 * @param {object} body
 * @return {Promise}
 */
function findOrCreateUser(query, body) {
    return _user2.default.findOrCreate(query, body);
}

/**
 * @function updateUser
 * @description Update existing user
 * @param {object} body
 * @param {Number} userId
 * @return {object}
 */
function updateUser(body, userId) {
    return _user2.default.update({ '_id': userId }, { $set: body }).then(function () {
        return getUserById(userId);
    });
}

/**
 * @function deleteUser
 * @description Delete user by id
 * @param {Number} userId
 * @return {object}
 */
function deleteUser(userId) {
    return _user2.default.findByIdAndRemove(userId);
}

exports.default = {
    isPasswordCorrect: isPasswordCorrect,
    findOneBy: findOneBy,
    getAllUsers: getAllUsers,
    getUserById: getUserById,
    createUser: createUser,
    findOrCreateUser: findOrCreateUser,
    updateUser: updateUser,
    deleteUser: deleteUser
};
module.exports = exports['default'];
//# sourceMappingURL=user.service.js.map
